list_admin_finder_php = ["admin.php","login.php","adminctrl.php","adminpage.php"
,"admin-page.php","admin-login.php","admin-ctrl.php","admin-control.php",
"login-admin.php","control-admin.php","ctrladmin.php","ctrl-admin.php"
,"loginadmin.php","login-admin.php","pageadmin.php","page-admin.php",
"admincontroller.php","admin-controller.php","controller-admin.php",
"controller-admin.php","panel.php","admin-panel.php","adminpanel.php",
"paneladmin.php","panel-admin.php"]

list_admin_finder_asp = ["admin","login","amdinctrl","amdinpage"
,"admin-page","admin-login","admin-ctrl","admin-control",
"login-admin","control-admin","ctrladmin","ctrl-admin"
,"loginadmin","login-admin","pageadmin","page-admin",
"admincontroller","admin-controller","controller-admin",
"controller-admin","panel","admin-panel","adminpanel",
"paneladmin","panel-admin"]
